==> jc-1.4.0.tar.gz: java/awt/geom/Area__24Intersection.h <==
// class java.awt.geom.Area$Intersection

// class file dependencies
// @dep_class 6f884190d053f007 java_awt_geom_Area__24Intersection
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_Area__24Intersection_H_
#define _JC_java_awt_geom_Area__24Intersection_H_

// Forward structure declarations
struct _jc_java_awt_geom_Area$object;
struct _jc_java_awt_geom_Area__24Segment$object;
struct _jc_java_awt_geom_Point2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Area__24Intersection$sub_refs	_jc_java_awt_geom_Area__24Intersection$sub_refs;
typedef struct _jc_java_awt_geom_Area__24Intersection$sub_nonrefs	_jc_java_awt_geom_Area__24Intersection$sub_nonrefs;
typedef struct _jc_java_awt_geom_Area__24Intersection$refs	_jc_java_awt_geom_Area__24Intersection$refs;
typedef struct _jc_java_awt_geom_Area__24Intersection$nonrefs	_jc_java_awt_geom_Area__24Intersection$nonrefs;
typedef struct _jc_java_awt_geom_Area__24Intersection$object	_jc_java_awt_geom_Area__24Intersection$object;

typedef const struct _jc_java_awt_geom_Area__24Intersection$vmethods	_jc_java_awt_geom_Area__24Intersection$vmethods;
typedef const struct _jc_java_awt_geom_Area__24Intersection$vtable	_jc_java_awt_geom_Area__24Intersection$vtable;
typedef const struct _jc_java_awt_geom_Area__24Intersection$vtype	_jc_java_awt_geom_Area__24Intersection$vtype;

// Constructors
extern void _jc_java_awt_geom_Area__24Intersection$method$_init$b347e1a461f66062(_jc_env *, struct _jc_java_awt_geom_Area__24Intersection$object *, struct _jc_java_awt_geom_Area$object *, struct _jc_java_awt_geom_Point2D$object *, jdouble, jdouble);

// Virtual methods structure
struct _jc_java_awt_geom_Area__24Intersection$vmethods {
};

// Vtable
struct _jc_java_awt_geom_Area__24Intersection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Area__24Intersection$vmethods	java_awt_geom_Area__24Intersection;
};

// Vtype
struct _jc_java_awt_geom_Area__24Intersection$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Area__24Intersection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24Intersection$sub_refs {
	struct _jc_java_awt_geom_Point2D$object	*p;
	struct _jc_java_awt_geom_Area__24Segment$object	*seg;
	struct _jc_java_awt_geom_Area$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Area__24Intersection$refs {
    _jc_java_awt_geom_Area__24Intersection$sub_refs	java_awt_geom_Area__24Intersection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24Intersection$sub_nonrefs {
	jdouble	ta;
	jdouble	tb;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Area__24Intersection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Area__24Intersection$sub_nonrefs	java_awt_geom_Area__24Intersection;
};

// Object instance structure
struct _jc_java_awt_geom_Area__24Intersection$object {
	_jc_java_awt_geom_Area__24Intersection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Area__24Intersection$vtype	*vtype;
	_jc_java_awt_geom_Area__24Intersection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Area__24Intersection$vtype _jc_java_awt_geom_Area__24Intersection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Area__24Intersection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Area__24Intersection$class_object;

#endif	/* _JC_java_awt_geom_Area__24Intersection_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/Area__24Intersection.h <==
// class java.awt.geom.Area$Intersection

// class file dependencies
// @dep_class 9d8be223420ea998 java_awt_geom_Area__24Intersection
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_Area__24Intersection_H_
#define _JC_java_awt_geom_Area__24Intersection_H_

// Forward structure declarations
struct _jc_java_awt_geom_Area$object;
struct _jc_java_awt_geom_Area__24Segment$object;
struct _jc_java_awt_geom_Point2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Area__24Intersection$sub_refs	_jc_java_awt_geom_Area__24Intersection$sub_refs;
typedef struct _jc_java_awt_geom_Area__24Intersection$sub_nonrefs	_jc_java_awt_geom_Area__24Intersection$sub_nonrefs;
typedef struct _jc_java_awt_geom_Area__24Intersection$refs	_jc_java_awt_geom_Area__24Intersection$refs;
typedef struct _jc_java_awt_geom_Area__24Intersection$nonrefs	_jc_java_awt_geom_Area__24Intersection$nonrefs;
typedef struct _jc_java_awt_geom_Area__24Intersection$object	_jc_java_awt_geom_Area__24Intersection$object;

typedef const struct _jc_java_awt_geom_Area__24Intersection$vmethods	_jc_java_awt_geom_Area__24Intersection$vmethods;
typedef const struct _jc_java_awt_geom_Area__24Intersection$vtable	_jc_java_awt_geom_Area__24Intersection$vtable;
typedef const struct _jc_java_awt_geom_Area__24Intersection$vtype	_jc_java_awt_geom_Area__24Intersection$vtype;

// Constructors
extern void _jc_java_awt_geom_Area__24Intersection$method$_init$b347e1a461f66062(_jc_env *, struct _jc_java_awt_geom_Area__24Intersection$object *, struct _jc_java_awt_geom_Area$object *, struct _jc_java_awt_geom_Point2D$object *, jdouble, jdouble) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_geom_Area__24Intersection$vmethods {
};

// Vtable
struct _jc_java_awt_geom_Area__24Intersection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Area__24Intersection$vmethods	java_awt_geom_Area__24Intersection;
};

// Vtype
struct _jc_java_awt_geom_Area__24Intersection$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Area__24Intersection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24Intersection$sub_refs {
	struct _jc_java_awt_geom_Point2D$object	*p;
	struct _jc_java_awt_geom_Area__24Segment$object	*seg;
	struct _jc_java_awt_geom_Area$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Area__24Intersection$refs {
    _jc_java_awt_geom_Area__24Intersection$sub_refs	java_awt_geom_Area__24Intersection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24Intersection$sub_nonrefs {
	jdouble	ta;
	jdouble	tb;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Area__24Intersection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Area__24Intersection$sub_nonrefs	java_awt_geom_Area__24Intersection;
};

// Object instance structure
struct _jc_java_awt_geom_Area__24Intersection$object {
	_jc_java_awt_geom_Area__24Intersection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Area__24Intersection$vtype	*vtype;
	_jc_java_awt_geom_Area__24Intersection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Area__24Intersection$vtype _jc_java_awt_geom_Area__24Intersection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Area__24Intersection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Area__24Intersection$class_object;

#endif	/* _JC_java_awt_geom_Area__24Intersection_H_ */
